%define tarname	Sphinx

# disable these for bootstrapping nose and sphinx
%define enable_tests 1
%define enable_doc 1

%if %enable_doc
%else 
%global __requires_exclude python.*\(sphinx-rtd-theme\)
%endif

Summary:	Python documentation generator
Name:		python-sphinx
Version:	1.4.9
Release:	%mkrel 1
License:	BSD
Group:		Development/Python
Url:		http://sphinx.pocoo.org/
Source0:	https://files.pythonhosted.org/packages/source/S/%{tarname}/%{tarname}-%{version}.tar.gz
Patch1:		skip_tests_on_bs.patch

BuildArch:	noarch
Requires:	python-pkg-resources
Requires:	python-docutils >= 0.7
Requires:	python-pygments >= 1.2
Requires:	python-jinja2 >= 2.3
BuildRequires:	pythonegg(2)(setuptools)
Requires:	python-pygments >= 1.2
Requires:       pythonegg(2)(six)
Requires:       python-sphinx-locales = %{version}-%{release}
Conflicts:      python3-sphinx < %{version}-%{release}
%if %enable_doc
BuildRequires:	python-docutils >= 0.7
BuildRequires:	python-jinja2 >= 2.3
BuildRequires:	pythonegg(2)(sphinx-rtd-theme)
BuildRequires:	pythonegg(2)(alabaster)
BuildRequires:	pythonegg(2)(six)
BuildRequires:	pythonegg(2)(imagesize)
%endif


%if %enable_tests
BuildRequires:	python-nose
BuildRequires:	python3-nose
BuildRequires:	python-pygments
BuildRequires:	python3-pygments
BuildRequires:  python-jinja2
BuildRequires:  python3-jinja2
BuildRequires:  python-mock
BuildRequires:  python3-mock
BuildRequires:	gettext
BuildRequires:	pythonegg(3)(docutils)
BuildRequires:	pythonegg(3)(snowballstemmer)
BuildRequires:	pythonegg(3)(babel)
BuildRequires:	pythonegg(3)(imagesize)
BuildRequires:	pythonegg(3)(alabaster)
BuildRequires:	pythonegg(3)(sphinx-rtd-theme)
%endif
BuildRequires:	pkgconfig(python)
BuildRequires:	pkgconfig(python3)
BuildRequires:	python3-setuptools


%description
Sphinx is a tool that facilitates the creation of beautiful
documentation for Python projects from reStructuredText sources. It
was originally created to format the new documentation for Python, but
has since been cleaned up in the hope that it will be useful in many
other projects.


%package -n python3-sphinx
Summary:	Python documentation generator
Group:		Development/Python
Requires:	python3-docutils
Requires:	python3-jinja2
Requires:	python3-pygments
Requires:       python3-six
Requires:       python-sphinx-locales = %{version}-%{release}
Conflicts:      python-sphinx < %{version}-%{release}

%description -n python3-sphinx
Sphinx is a tool that makes it easy to create intelligent and
beautiful documentation for Python projects (or other documents
consisting of multiple reStructuredText sources), written by Georg
Brandl. It was originally created to translate the new Python
documentation, but has now been cleaned up in the hope that it will be
useful to many other projects.


%if %enable_doc
%package doc
Summary:	Documentation for %{name}
Group:		Documentation
License:	BSD
Requires:	%{name} = %{version}-%{release}

%description doc
Sphinx is a tool that makes it easy to create intelligent and
beautiful documentation for Python projects (or other documents
consisting of multiple reStructuredText sources), written by Georg
Brandl. It was originally created to translate the new Python
documentation, but has now been cleaned up in the hope that it will be
useful to many other projects.

This package contains documentation in reST and HTML formats.
%endif


%package locales
Summary:	Locales for python-sphinx and python3-sphinx
Group:          Development/Python
Conflicts:      python-sphinx < %{version}-%{release}
Conflicts:      python3-sphinx < %{version}-%{release}

%description locales
Sphinx is a tool that makes it easy to create intelligent and
beautiful documentation for Python projects (or other documents
consisting of multiple reStructuredText sources), written by Georg
Brandl. It was originally created to translate the new Python
documentation, but has now been cleaned up in the hope that it will be
useful to many other projects.

This package contains locales.


%prep
%setup -q -n %{tarname}-%{version}
%patch1 -p1

sed '1d' -i sphinx/pycode/pgen2/token.py

cp -a . %{py3dir}

%build
%py2_build
pushd %{py3dir}
%py3_build
popd

%if %enable_doc
pushd doc
make html
make man
rm -rf _build/html/.buildinfo
mv _build/html ..
popd
%endif


%install
pushd %{py3dir}
%py3_install
for i in sphinx-{apidoc,autogen,build,quickstart}; do
    mv %{buildroot}%{_bindir}/$i %{buildroot}%{_bindir}/$i-%{python3_version}
    ln -s $i-%{python3_version} %{buildroot}%{_bindir}/$i-3
done
popd

%py2_install 
for i in sphinx-{apidoc,autogen,build,quickstart}; do
    mv %{buildroot}%{_bindir}/$i %{buildroot}%{_bindir}/$i-%{python2_version}
    ln -s $i-%{python2_version} %{buildroot}%{_bindir}/$i-2
    ln -s $i-2 %{buildroot}%{_bindir}/$i
done

%if %enable_doc
pushd doc
# Deliver man pages
install -d %{buildroot}%{_mandir}/man1
mv _build/man/sphinx-*.1 %{buildroot}%{_mandir}/man1/
for f in %{buildroot}%{_mandir}/man1/sphinx-*.1;
do
    cp -p $f $(echo $f | sed -e "s|.1$|-%{python3_version}.1|")
done
popd

# Deliver rst files
rm -rf doc/_build
sed -i 's|python ../sphinx-build.py|/usr/bin/sphinx-build|' doc/Makefile
mv doc reST
%endif

# Remove language files, they're identical to the ones from the
# Python 2 build that will be moved to /usr/share below
find %{buildroot}%{python3_sitelib}/sphinx/locale -maxdepth 1 -mindepth 1 -type d -not -path '*/\.*' -exec rm -rf '{}' \;

# Move language files to /usr/share;
# patch to support this incorporated in 0.6.6
pushd %{buildroot}%{python2_sitelib}

for lang in `find sphinx/locale -maxdepth 1 -mindepth 1 -type d -not -path '*/\.*' -printf "%f "`;
do
  install -d %{buildroot}%{_datadir}/sphinx/locale/$lang
  install -d %{buildroot}%{_datadir}/locale/$lang/LC_MESSAGES
  mv sphinx/locale/$lang/LC_MESSAGES/sphinx.js \
     %{buildroot}%{_datadir}/sphinx/locale/$lang/
  mv sphinx/locale/$lang/LC_MESSAGES/sphinx.mo \
    %{buildroot}%{_datadir}/locale/$lang/LC_MESSAGES/
  rm -rf sphinx/locale/$lang
done
popd
%find_lang sphinx

# Language files; Since these are javascript, it's not immediately obvious to
# find_lang that they need to be marked with a language.
(cd %{buildroot} && find . -name 'sphinx.js') | sed -e 's|^.||' | sed -e \
  's:\(.*/locale/\)\([^/_]\+\)\(.*\.js$\):%lang(\2) \1\2\3:' \
  >> sphinx.lang


%check
%if %enable_tests
LANG=en_US.UTF-8 make test
pushd %{py3dir}
LANG=en_US.UTF-8 PYTHON=python3 make test
popd
%endif

%files
%license LICENSE 
%doc AUTHORS CHANGES EXAMPLES
%exclude %{_bindir}/sphinx-*-%{python3_version}
%exclude %{_bindir}/sphinx-*-3
%{_bindir}/sphinx-*
%{python2_sitelib}/*
%exclude %{_mandir}/man1/sphinx-*-%{python3_version}.1*
%if %enable_doc
%{_mandir}/man1/*
%endif

%files -n python3-sphinx
%license LICENSE 
%doc AUTHORS CHANGES EXAMPLES
%{_bindir}/sphinx-*-%{python3_version}
%{_bindir}/sphinx-*-3
%{python3_sitelib}/*
%if %enable_doc
%{_mandir}/man1/sphinx-*-%{python3_version}.1*
%endif

%files locales -f sphinx.lang
%dir %{_datadir}/sphinx/
%dir %{_datadir}/sphinx/locale
%dir %{_datadir}/sphinx/locale/*


%if %enable_doc
%files doc
%doc html reST
%endif



%changelog
* Sat Feb 04 2017 philippem <philippem> 1.4.9-1.mga6
+ Revision: 1084838
- update to 1.4.9

* Mon Jul 18 2016 daviddavid <daviddavid> 1.4.1-4.mga6
+ Revision: 1042456
- add upstream patch to fix testsuite failure with new python 3.5.2:
  * https://github.com/sphinx-doc/sphinx/issues/2519

* Tue May 10 2016 philippem <philippem> 1.4.1-3.mga6
+ Revision: 1012063
- move locales in a sub package

* Fri Apr 29 2016 philippem <philippem> 1.4.1-2.mga6
+ Revision: 1007865
- enable tests and docs

* Fri Apr 29 2016 philippem <philippem> 1.4.1-1.mga6
+ Revision: 1007840
- update to 1.4.1 first build without doc

* Sat Feb 20 2016 umeabot <umeabot> 1.3.1-6.mga6
+ Revision: 971139
- Mageia 6 Mass Rebuild

* Sat Oct 10 2015 philippem <philippem> 1.3.1-5.mga6
+ Revision: 889355
- rebuild with docs and tests

* Sat Oct 10 2015 tv <tv> 1.3.1-4.mga6
+ Revision: 889009
- rebuild for python 3.5

* Wed Oct 07 2015 philippem <philippem> 1.3.1-3.mga6
+ Revision: 887052
- rebuild for Python 3.5, bootstrap

* Mon Sep 21 2015 philippem <philippem> 1.3.1-2.mga6
+ Revision: 882091
- add symlinks for Python3 version mga#16789

* Thu Aug 20 2015 joequant <joequant> 1.3.1-1.mga6
+ Revision: 866945
- add mock
- add docs
- add requires
- rebuild with docs

* Thu Aug 20 2015 joequant <joequant> 1.3.1-0.2.mga6
+ Revision: 866929
- fix bootstrap issues

* Thu Aug 20 2015 joequant <joequant> 1.3.1-0.1.mga6
+ Revision: 866908
- add 1.3.1 sources
- update to 1.3.1 with bootstrap

* Wed Oct 15 2014 umeabot <umeabot> 1.2.3-4.mga5
+ Revision: 744754
- Second Mageia 5 Mass Rebuild

* Sat Sep 27 2014 tv <tv> 1.2.3-3.mga5
+ Revision: 729800
- rebuild for missing pythoneggs deps

* Tue Sep 16 2014 umeabot <umeabot> 1.2.3-2.mga5
+ Revision: 688346
- Mageia 5 Mass Rebuild

* Tue Sep 09 2014 philippem <philippem> 1.2.3-1.mga5
+ Revision: 674394
- update to 1.2.3

* Sat May 31 2014 pterjan <pterjan> 1.2.2-2.mga5
+ Revision: 629025
- Rebuild for new Python

* Sat Mar 08 2014 philippem <philippem> 1.2.2-1.mga5
+ Revision: 601314
- update to 1.2.2

* Tue Oct 22 2013 umeabot <umeabot> 1.1.3-7.mga4
+ Revision: 544172
- Mageia 4 Mass Rebuild

* Tue Oct 15 2013 pterjan <pterjan> 1.1.3-6.mga4
+ Revision: 499416
- Rebuild to add different pythonegg provides for python 2 and 3

* Wed Jul 03 2013 philippem <philippem> 1.1.3-5.mga4
+ Revision: 449988
- Fixes quoting issue in inheritance_diagram.py

* Tue Jul 02 2013 philippem <philippem> 1.1.3-4.mga4
+ Revision: 449676
- add Python 3

* Wed Jan 23 2013 sander85 <sander85> 1.1.3-3.mga3
+ Revision: 391602
- Fix manpage writer in expectation of docutils 0.10 API change (upstream#998)

* Sun Jan 13 2013 umeabot <umeabot> 1.1.3-2.mga3
+ Revision: 379544
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sun Sep 16 2012 philippem <philippem> 1.1.3-1.mga3
+ Revision: 294491
- New version 1.1.3

* Thu Nov 03 2011 lebedov <lebedov> 1.1.2-1.mga2
+ Revision: 162399
- Update to 1.1.2.

* Tue Oct 11 2011 lebedov <lebedov> 1.1-1.mga2
+ Revision: 153944
- Update to 1.1.

* Sat Sep 24 2011 fwang <fwang> 1.0.8-1.mga2
+ Revision: 147323
- new version 1.0.8

* Mon Feb 21 2011 ahmad <ahmad> 1.0.7-2.mga1
+ Revision: 55584
- rebuild to make all pythonegg requires/provides lowercase

* Thu Feb 03 2011 ahmad <ahmad> 1.0.7-1.mga1
+ Revision: 46761
- update to 1.0.7

* Mon Jan 31 2011 dmorgan <dmorgan> 1.0.5-7.mga1
+ Revision: 45405
- Enable back as python-nose have been rebuild

* Mon Jan 31 2011 dmorgan <dmorgan> 1.0.5-6.mga1
+ Revision: 45371
- Bump release
- bootstrap for rebuild gainst

* Mon Jan 31 2011 dmorgan <dmorgan> 1.0.5-5.mga1
+ Revision: 45350
- bootstrap because we need to rebuild python-nose
- Rebuild against python 2.7

  + pterjan <pterjan>
    - Re-enable tests

* Mon Jan 17 2011 pterjan <pterjan> 1.0.5-4.mga1
+ Revision: 21282
- Enable bootstrap
- Rebuild for python 2.7

* Thu Jan 13 2011 ahmad <ahmad> 1.0.5-3.mga1
+ Revision: 8372
- enable doc and tests

* Thu Jan 13 2011 ahmad <ahmad> 1.0.5-2.mga1
+ Revision: 8357
- disable doc and tests for now
- replace deprecated %%py_requires macro with BR python-devel
- imported package python-sphinx

